<!-- Start Wrapper  -->
<table width="640" cellpadding="0" cellspacing="0" border="0" class="mobileOff" bgcolor="#FFFFFF">
  <tr>
    <td align="center">

      <!-- Start Container  -->
      <table width="640" cellpadding="0" cellspacing="0" border="0" class="container">
        <tr>
          <td width="600" class="mobile">
            <img src="http://placehold.it/640x400" width="640" height="400" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
          </td>
        </tr>
      </table>
      <!-- End Container  -->

    </td>
  </tr>
</table>
<!-- End Wrapper  -->

<!--[if !mso]><!-- -->
<div class="mobileOn" style="font-size: 0; max-height: 0; overflow: hidden; display: none">
  <table width="320" cellspacing="0" cellpadding="0" border="0" class="wrapper" align="center">
    <tr>
      <td align="center">
        <img src="http://placehold.it/320x300" width="320" height="300" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
      </td>
    </tr>
  </table>
</div>
<!--<![endif]-->
