<!-- Start Wrapper -->
<table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="FFFFFF">
    <tr>
        <td height="20" style="font-size:20px; line-height:20px;"> </td><!-- Spacer -->
    </tr>
    <tr>
        <td align="center">

            <!-- Start Container -->
            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                <tr>
                    <td width="300" class="mobile" style="font-size:12px; line-height:18px;" align="center">

                        <!-- Start Content -->
                        <table width="290" cellpadding="0" cellspacing="0" border="0" class="container" align="center">
                            <tr>
                                <td width="290" class="mobile" style="font-size:12px; line-height:18px;" align="center">
                                    <img src="http://www.placehold.it/290x200" width="290" height="200" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                </td>
                            </tr>
                            <tr>
                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                            </tr>
                            <tr>
                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                    Title One
                                </td>
                            </tr>
                            <tr>
                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                            </tr>
                            <tr>
                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;">
                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                                </td>
                            </tr>
                            <tr>
                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                            </tr>
                            <tr>
                                <td class="mobile" style="font-size:14px; line-height:20px;" align="center">

                                    <!-- Start Button -->
                                    <table width="190" cellpadding="0" cellspacing="0" align="center" border="0">
                                        <tr>
                                            <td width="190" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family:arial, sans-serif; font-size: 16px; color: #ffffff; line-height:18px; border-radius:3px;">
                                                <a href="" target="_blank" alias="" style="font-family:arial, sans-serif; text-decoration: none; color: #ffffff;">My Button ></a>
                                            </td>
                                        </tr>
                                    </table>
                                    <!-- End Button -->

                                </td>
                            </tr>
                             <tr>
                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                            </tr>
                        </table>
                        <!-- End Content -->

                    </td>
                    <td width="300" class="mobile" style="font-size:12px; line-height:18px;" align="center">

                        <!-- Start Content -->
                        <table width="290" cellpadding="0" cellspacing="0" border="0" class="container" align="center">
                            <tr>
                                <td width="290" class="mobile" style="font-size:12px; line-height:18px;">
                                    <img src="http://www.placehold.it/290x200" width="290" height="200" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                </td>
                            </tr>
                            <tr>
                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                            </tr>
                            <tr>
                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                    Title Two
                                </td>
                            </tr>
                            <tr>
                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                            </tr>
                            <tr>
                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;">
                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                                </td>
                            </tr>
                            <tr>
                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                            </tr>
                            <tr>
                                <td class="mobile" style="font-size:14px; line-height:20px;" align="center">

                                    <!-- Start Button -->
                                    <table width="190" cellpadding="0" cellspacing="0" align="center" border="0">
                                        <tr>
                                            <td width="190" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family:arial, sans-serif; font-size: 16px; color: #ffffff; line-height:18px; border-radius:3px;">
                                                <a href="" target="_blank" alias="" style="font-family:arial, sans-serif; text-decoration: none; color: #ffffff;">My Button ></a>
                                            </td>
                                        </tr>
                                    </table>
                                    <!-- End Button -->

                                </td>
                            </tr>
                            <tr>
                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                            </tr>
                        </table>
                        <!-- End Content -->

                    </td>
                </tr>
            </table>
            <!-- End Container -->

        </td>
    </tr>
</table>
<!-- End Wrapper -->
