<!-- Start Wrapper -->
<table width="100%" cellpadding="0" cellspacing="0" border="0" bgcolor="#545150">
  <tr>
    <td height="15" style="font-size:10px; line-height:10px;">&nbsp;</td>
  </tr>
  <tr>
    <td align="center">

      <!-- Start Container -->
      <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
        <tr>
          <td width="140" class="mobile50" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
            <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link One</a>
          </td>
          <td width="10" style="color:#666666;" align="center">|</td>
          <td width="140" class="mobile50" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
            <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Two</a>
          </td>
          <td width="10" style="color:#666666;" align="center" class="mobileOff">|</td>
          <td width="140" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
            <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Three</a>
          </td>
          <td width="10" style="color:#666666;" align="center" class="mobileOff">|</td>
          <td width="140" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
            <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Four</a>
          </td>
        </tr>
     </table>
     <!-- End Container -->

    </td>
  </tr>
  <tr>
    <td height="15" style="font-size:10px; line-height:10px;">&nbsp;</td>
  </tr>
</table>
<!-- End Wrapper -->
