{% load static sekizai_tags sass_tags %}


{# Some parts of these are overridden by the django-shop django-angular.scss #}
{% addtoblock "ext-css" %}<link rel="stylesheet" type="text/css" href="{% static 'djng/css/styles.css' %}" />{% endaddtoblock %}
{% addtoblock "ext-css" %}<link rel="stylesheet" type="text/css" href="{% static 'djng/css/bootstrap3.css' %}" />{% endaddtoblock %}
{# imports the shop django-angular.scss #}
{% addtoblock "ext-css" %}<link rel="stylesheet" type="text/css" href="{% sass_src 'shop_subscribe/css/djng-success.scss' %}" />{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'djng/js/django-angular.min.js' %}" type="text/javascript"></script>{% endaddtoblock %}

{% block content %}{% endblock %}
