<!-- Start Wrapper  -->
<table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
  <tr>
    <td height="10" style="font-size:10px; line-height:10px;">&nbsp;</td>
  </tr>
  <tr>
    <td align="center">

        <!-- Start Container  -->
        <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
          <tr>
            <td width="300" class="mobile" align="center">
              <img src="http://placehold.it/50x50" width="50" height="50" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
            </td>
          </tr>
        </table>
        <!-- End Container  -->

    </td>
  </tr>
  <tr>
    <td height="10" style="font-size:10px; line-height:10px;">&nbsp;</td>
  </tr>
</table>
<!-- End Wrapper  -->
