<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>

    <title>Newsletter Template - Email Framework</title>
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=0" />
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
        <!--[if !mso]><!-->
        <meta http-equiv="X-UA-Compatible" content="IE=edge" />
        <!--<![endif]-->

    <style type="text/css">

        .ReadMsgBody { width: 100%; background-color: #d8eaf8; }
        .ExternalClass { width: 100%; background-color: #d8eaf8; }
        body { width: 100%; background-color: #d8eaf8; margin: 0; padding: 0; -webkit-font-smoothing: antialiased; font-family: Arial, Times, serif }
        table { border-collapse: collapse !important; mso-table-lspace: 0pt; mso-table-rspace: 0pt; }

        @-ms-viewport{ width: device-width; }

        @media only screen and (max-width: 639px){
        .wrapper{ width:100%;  padding: 0 !important; }
        }

        @media only screen and (max-width: 480px){
        .centerClass{ margin:0 auto !important; }
        .imgClass{ width:100% !important; height:auto; }
        .wrapper{ width:320px; padding: 0 !important; }
        .header{ width:320px; padding: 0 !important; background-image: url(http://placehold.it/320x400) !important; }
        .container{ width:300px;  padding: 0 !important; }
        .mobile{ width:300px; display:block; padding: 0 !important; text-align:center !important;}
        .mobile50{ width:300px; padding: 0 !important; text-align:center; }
        *[class="mobileOff"] { width: 0px !important; display: none !important; }
        *[class*="mobileOn"] { display: block !important; max-height:none !important; }
        }

    </style>

    <!--[if gte mso 15]>
    <style type="text/css">
        table { font-size:1px; line-height:0; mso-margin-top-alt:1px;mso-line-height-rule: exactly; }
        * { mso-line-height-rule: exactly; }
    </style>
    <![endif]-->

</head>
<body marginwidth="0" marginheight="0" leftmargin="0" topmargin="0" style="background-color:#d8eaf8;  font-family:Arial,serif; margin:0; padding:0; min-width: 100%; -webkit-text-size-adjust:none; -ms-text-size-adjust:none;">

    <!--[if !mso]><!-- -->
    <img style="min-width:640px; display:block; margin:0; padding:0" class="mobileOff" width="640" height="1" src="http://s14.postimg.org/7139vfhzx/spacer.gif">
    <!--<![endif]-->

    <!-- Start Background -->
    <table width="100%" cellpadding="0" cellspacing="0" border="0" bgcolor="#d8eaf8">
        <tr>
            <td width="100%" valign="top" align="center">

                 <!-- Start Wrapper -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="mobileOff">
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" align="left" style="font-size:12px; line-height:18px;">
                                        This is your preheader!
                                    </td>
                                    <td width="300" class="mobile" align="right" style="font-size:12px; line-height:18px;">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#222222; text-decoration:underline;">Trouble seeing this email?</a>
                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->


                <!-- Start Wrapper -->
                <table width="800" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <img src="https://cdn2.iconfinder.com/data/icons/social-buttons-2/512/mail-64.png" width="48" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->



                <!-- Start Wrapper -->
                <table width="800" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#0073ba" style="border-bottom:#015f99 3px solid;">
                    <tr>
                        <td height="15" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="120" class="mobile50" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link One</a>
                                    </td>
                                    <td width="120" class="mobile50" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Two</a>
                                    </td>
                                    <td width="120" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Three</a>
                                    </td>
                                    <td width="120" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Four</a>
                                    </td>
                                    <td width="120" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Five</a>
                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="15" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->



                <!-- Start Wrapper -->
                <table width="800" height="400" cellpadding="0" cellspacing="0" border="0" class="header" background="http://placehold.it/800x400" style="background-image: url(http://placehold.it/800x400);">
                    <tr>
                        <td align="center">
                            <!--[if gte mso 9]>
                            <v:rect xmlns:v="urn:schemas-microsoft-com:vml" fill="true" stroke="false" style="width:640px">
                            <v:fill type="frame" src="http://placehold.it/800x400" color="#ffffff" />
                            <v:textbox style="mso-fit-shape-to-text:true" inset="0,0,0,0">
                            <div style="font-size:1px;line-height:1px">
                            <table width="800" cellspacing="0" cellpadding="0" border="0" align="center">
                            <tbody>
                            <tr>
                            <td height="400" align="center">
                            <![endif]-->

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td align="center" class="mobile" style="font-family: Arial; font-size:40px; line-height:46px; font-weight:bold; color:#FFFFFF;">
                                        Email Framework.
                                    </td>
                                </tr>
                                 <tr>
                                    <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                </tr>
                                <tr>
                                    <td align="center" class="mobile" style="font-family: Arial; font-size:14px; line-height:20px; color:#4d4d4d;">
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed porta purus porttitor enim scelerisque, vel malesuada lorem mattis. Curabitur ac orci libero.
                                    </td>
                                </tr>
                                 <tr>
                                    <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                </tr>
                                <tr>
                                    <td align="center" class="mobile" style="font-size:14px; line-height:20px;">

                                        <!-- Start Button -->
                                        <table width="170" cellpadding="0" cellspacing="0" align="center" border="0">
                                            <tr>
                                                <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px;">
                                                    <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Button ></a>
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Button -->

                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                            <!--[if gte mso 9]>
                            </td>
                            </tr>
                            </tbody>
                            </table>
                            </div>
                            </v:textbox>
                            </v:rect>
                            <![endif]-->

                        </td>
                    </tr>
                </table>
                <!-- End Wrapper -->



                <!-- Start Wrapper -->
                <table width="800" cellpadding="0" cellspacing="0" align="center" border="0" class="wrapper" bgcolor="#ffffff">
                    <tbody>
                        <tr>
                            <td height="40" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                        </tr>
                        <tr>
                            <td align="center" bgcolor="#ffffff">

                                <!-- Start Container -->
                                <table width="600" cellpadding="0" cellspacing="0" align="center" border="0" class="container">
                                    <tr>
                                        <td align="center" class="mobile" style="font-family: Arial; font-size:20px; line-height:26px;">
                                                Responsive HTML email!
                                        </td>
                                    </tr>
                                    <tr>
                                        <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                                    </tr>
                                    <tr>
                                        <td align="center" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                            Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque, efficitur sit amet luctus eget, malesuada eu turpis. Duis bibendum sem pharetra quam ullamcorper malesuada. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos.
                                        </td>
                                    </tr>

                                    <tr>
                                        <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                                    </tr>

                                    <tr>
                                        <td align="center">

                                            <!-- Start Button -->
                                            <table width="170" cellpadding="0" cellspacing="0" align="center" border="0">
                                                <tr>
                                                    <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px;">
                                                        <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Button ></a>
                                                    </td>
                                                </tr>
                                            </table>
                                            <!-- End Button -->

                                        </td>
                                    </tr>
                                </table>
                                <!-- End Container -->

                            </td>
                        </tr>
                        <tr>
                            <td height="40" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                        </tr>
                    </tbody>
                </table>
                <!-- End Wrapper -->



                <!-- Start Wrapper -->
                <table width="800" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#f1f1f1">
                    <tr>
                        <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <!-- Start Content -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td width="280" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">
                                                    <img src="http://www.placehold.it/280x200" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->
                                    </td>
                                    <td height="20" style="" class="mobileOn"></td>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <!-- Start Content -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td style="font-family:arial; font-size:20px; line-height:26px;" align="left">
                                                    Title One
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque, efficitur sit amet luctus eget, malesuada eu turpis. Duis bibendum sem pharetra quam ullamcorper malesuada.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    <!-- Start Button -->
                                                    <table width="170" cellpadding="0" cellspacing="0" align="left" border="0">
                                                        <tr>
                                                            <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px;">
                                                                <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->
                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->



                <!-- Start Wrapper -->
                <table width="800" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#ffffff">
                    <tr>
                        <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <!-- Start Content -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td style="font-family:arial; font-size:20px; line-height:26px;" align="left">
                                                    Title Two
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque, efficitur sit amet luctus eget, malesuada eu turpis. Duis bibendum sem pharetra quam ullamcorper malesuada.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    <!-- Start Button -->
                                                    <table width="170" cellpadding="0" cellspacing="0" align="left" border="0">
                                                        <tr>
                                                            <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px;">
                                                                <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->
                                    </td>
                                    <td height="20" style="" class="mobileOn"></td>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <!-- Start Content -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td width="280" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">
                                                    <img src="http://www.placehold.it/280x200" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->
                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->



                <!-- Start Wrapper -->
                <table width="800" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#f1f1f1">
                    <tr>
                        <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <!-- Start Content -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td width="280" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">
                                                    <img src="http://www.placehold.it/280x200" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->
                                    </td>
                                    <td height="20" style="" class="mobileOn"></td>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <!-- Start Content -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td style="font-family:arial; font-size:20px; line-height:26px;" align="left">
                                                    Title Three
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque, efficitur sit amet luctus eget, malesuada eu turpis. Duis bibendum sem pharetra quam ullamcorper malesuada.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    <!-- Start Button -->
                                                    <table width="170" cellpadding="0" cellspacing="0" align="left" border="0">
                                                        <tr>
                                                            <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px;">
                                                                <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->
                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->



                <!-- Start Wrapper -->
                <table width="800" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#ffffff">
                    <tr>
                        <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <!-- Start Container -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td width="280" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">
                                                    <img src="http://www.placehold.it/280x200" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td style="font-family:arial; font-size:20px; line-height:26px;" align="left">
                                                    Title Four
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque, efficitur sit amet luctus eget, malesuada eu turpis. Duis bibendum sem pharetra quam ullamcorper malesuada.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    <!-- Start Button -->
                                                    <table width="170" cellpadding="0" cellspacing="0" align="left" border="0">
                                                        <tr>
                                                            <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px;">
                                                                <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Container -->
                                    </td>
                                    <td height="20" style="" class="mobileOn"></td>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                         <!-- Start Content -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td width="280" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">
                                                    <img src="http://www.placehold.it/280x200" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td style="font-family:arial; font-size:20px; line-height:26px;" align="left">
                                                    Title Five
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque, efficitur sit amet luctus eget, malesuada eu turpis. Duis bibendum sem pharetra quam ullamcorper malesuada.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    <!-- Start Button -->
                                                    <table width="170" cellpadding="0" cellspacing="0" align="left" border="0">
                                                        <tr>
                                                            <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px;">
                                                                <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->
                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->



                 <!-- Start Wrapper -->
                 <table width="800" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#f1f1f1">
                     <tr>
                         <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                     </tr>
                     <tr>
                         <td align="center">

                             <!-- Start Container -->
                             <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                 <tr>
                                     <td width="200" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                         <!-- Start Content -->
                                        <table width="180" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td width="180" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">
                                                    <img src="http://www.placehold.it/180x120" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td style="font-family:arial; font-size:20px; line-height:26px;" align="left">
                                                    Title Six
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    <!-- Start Button -->
                                                    <table width="170" cellpadding="0" cellspacing="0" align="left" border="0">
                                                        <tr>
                                                            <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px;">
                                                                <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->
                                     </td>
                                     <td height="20" style="" class="mobileOn"></td>
                                     <td width="200" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                         <!-- Start Content -->
                                        <table width="180" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td width="180" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">
                                                    <img src="http://www.placehold.it/180x120" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td style="font-family:arial; font-size:20px; line-height:26px;" align="left">
                                                    Title Seven
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    <!-- Start Button -->
                                                    <table width="170" cellpadding="0" cellspacing="0" align="left" border="0">
                                                        <tr>
                                                            <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px;">
                                                                <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->
                                     </td>
                                     <td height="20" style="" class="mobileOn"></td>
                                     <td width="200" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                         <!-- Start Content -->
                                        <table width="180" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td width="180" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">
                                                    <img src="http://www.placehold.it/180x120" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td style="font-family:arial; font-size:20px; line-height:26px;" align="left">
                                                    Title Eight
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="left" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                                    <!-- Start Button -->
                                                    <table width="170" cellpadding="0" cellspacing="0" align="left" border="0">
                                                        <tr>
                                                            <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px;">
                                                                <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->
                                     </td>
                                 </tr>
                             </table>
                             <!-- End Container -->

                         </td>
                     </tr>
                     <tr>
                         <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                     </tr>
                 </table>
                 <!-- End Wrapper -->



                <!-- Start Wrapper -->
                <table width="800" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="150" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <img src="http://www.placehold.it/130x50" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                    </td>
                                    <td height="20" style="" class="mobileOn"></td>
                                    <td width="150" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <img src="http://www.placehold.it/130x50" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                    </td>
                                    <td height="20" style="" class="mobileOn"></td>
                                    <td width="150" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <img src="http://www.placehold.it/130x50" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                    </td>
                                    <td height="20" style="" class="mobileOn"></td>
                                    <td width="150" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="center">
                                        <img src="http://www.placehold.it/130x50" width="" height="" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                    </td>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="40" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->



                <!-- Start Wrapper -->
                <table width="800" cellpadding="0" cellspacing="0" align="center" border="0" class="wrapper" bgcolor="#0073ba">
                    <tbody>
                        <tr>
                            <td height="40" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                        </tr>
                        <tr>
                            <td align="center">

                                <!-- Start Container -->
                                <table width="600" cellpadding="0" cellspacing="0" align="center" border="0" class="container">
                                    <tr>
                                        <td align="center" class="mobile" style="font-family: Arial; font-size:20px; line-height:26px; font-weight:bold; color:#FFFFFF;">
                                            Download this template
                                        </td>
                                    </tr>
                                    <tr>
                                        <td height="10" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                                    </tr>
                                    <tr>
                                        <td align="center" style="font-family: Arial; font-size: 14px; color: #4d4d4d; line-height:18px; color:#FFFFFF;">
                                            Lorem ipsum dolor sit amet, consectetur.
                                        </td>
                                    </tr>
                                    <tr>
                                        <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                                    </tr>
                                    <tr>
                                        <td align="center">

                                            <!-- Start Button -->
                                            <table width="170" cellpadding="0" cellspacing="0" align="center" border="0">
                                                <tr>
                                                    <td width="170" height="36" bgcolor="#0073ba" align="center" valign="middle" style="font-family: Arial; font-size: 14px; color: #ffffff; line-height:20px; border: 3px solid #FFFFFF;">
                                                        <a href="" target="_blank" alias="" style="font-family: Arial; text-decoration: none; color: #ffffff; text-transform:uppercase; font-weight:bold; letter-spacing:1px;">Download ></a>
                                                    </td>
                                                </tr>
                                            </table>
                                            <!-- End Button -->

                                        </td>
                                    </tr>
                                </table>
                                <!-- End Container -->

                            </td>
                        </tr>
                        <tr>
                            <td height="40" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                        </tr>
                    </tbody>
                </table>
                <!-- End Wrapper -->



                <!-- Start Wrapper -->
                <table width="800" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">
                                        &copy; 2015 - Email Framework
                                    </td>
                                    <td height="10" style="" class="mobileOn"></td>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;" align="right">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#525252; text-decoration:underline;">Unsubscribe</a>
                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->

            </td>
        </tr>
    </table>
    <!-- End Background -->

</body>
</html>
